import { Component, ElementRef, Inject, Directive, NgModule } from '@angular/core';
import { registerElement } from '@nativescript/angular';
import { ObservableArray } from '@nativescript/core';
import { RadRadialGauge, RadialScale, ScaleStyle, RadialBarIndicator, BarIndicatorStyle, RadialNeedle, TitleStyle, SubtitleStyle, NeedleStyle } from 'nativescript-ui-gauge';

class RadRadialGaugeComponent {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        this._radialGauge = _elementRef.nativeElement;
    }
    get nativeElement() {
        return this._radialGauge;
    }
    get radialGauge() {
        return this._radialGauge;
    }
}
RadRadialGaugeComponent.decorators = [
    { type: Component, args: [{
                selector: "RadRadialGauge",
                template: ``
            },] }
];
RadRadialGaugeComponent.ctorParameters = () => [
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialScaleDirective {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        this._radialScale = this._elementRef.nativeElement;
    }
    get radialScale() {
        return this._radialScale;
    }
}
TKRadialScaleDirective.decorators = [
    { type: Directive, args: [{
                selector: "RadialScale"
            },] }
];
TKRadialScaleDirective.ctorParameters = () => [
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialBarIndicatorDirective {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        this._barIndicator = this._elementRef.nativeElement;
    }
    get radialScale() {
        return this._barIndicator;
    }
}
TKRadialBarIndicatorDirective.decorators = [
    { type: Directive, args: [{
                selector: "RadialBarIndicator"
            },] }
];
TKRadialBarIndicatorDirective.ctorParameters = () => [
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialNeedleDirective {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        this._radialNeedle = this._elementRef.nativeElement;
    }
    get radialNeedle() {
        return this._radialNeedle;
    }
}
TKRadialNeedleDirective.decorators = [
    { type: Directive, args: [{
                selector: "RadialNeedle",
            },] }
];
TKRadialNeedleDirective.ctorParameters = () => [
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialGaugeScalesDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const scale = this._elementRef.nativeElement;
        const gauge = this.owner.radialGauge;
        if (gauge.scales) {
            gauge.scales.push(scale);
        }
        else {
            gauge.scales = new ObservableArray([scale]);
        }
    }
}
TKRadialGaugeScalesDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialGaugeScales]"
            },] }
];
TKRadialGaugeScalesDirective.ctorParameters = () => [
    { type: RadRadialGaugeComponent, decorators: [{ type: Inject, args: [RadRadialGaugeComponent,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialScaleStyleDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const radialScaleStyle = this._elementRef.nativeElement;
        this.owner.radialScale.scaleStyle = radialScaleStyle;
    }
}
TKRadialScaleStyleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialScaleStyle]"
            },] }
];
TKRadialScaleStyleDirective.ctorParameters = () => [
    { type: TKRadialScaleDirective, decorators: [{ type: Inject, args: [TKRadialScaleDirective,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialScaleIndicatorsDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const barIndicator = this._elementRef.nativeElement;
        const scale = this.owner.radialScale;
        if (scale.indicators) {
            scale.indicators.push(barIndicator);
        }
        else {
            scale.indicators = new ObservableArray([barIndicator]);
        }
    }
}
TKRadialScaleIndicatorsDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialScaleIndicators]"
            },] }
];
TKRadialScaleIndicatorsDirective.ctorParameters = () => [
    { type: TKRadialScaleDirective, decorators: [{ type: Inject, args: [TKRadialScaleDirective,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialBarIndicatorStyleDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const indicatorStyle = this._elementRef.nativeElement;
        this.owner.radialScale.indicatorStyle = indicatorStyle;
    }
}
TKRadialBarIndicatorStyleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialBarIndicatorStyle]"
            },] }
];
TKRadialBarIndicatorStyleDirective.ctorParameters = () => [
    { type: TKRadialBarIndicatorDirective, decorators: [{ type: Inject, args: [TKRadialBarIndicatorDirective,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialGaugeTitleStyleDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const style = this._elementRef.nativeElement;
        this.owner.radialGauge.titleStyle = style;
    }
}
TKRadialGaugeTitleStyleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialGaugeTitleStyle]"
            },] }
];
TKRadialGaugeTitleStyleDirective.ctorParameters = () => [
    { type: RadRadialGaugeComponent, decorators: [{ type: Inject, args: [RadRadialGaugeComponent,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialGaugeSubtitleStyleDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const style = this._elementRef.nativeElement;
        this.owner.radialGauge.subtitleStyle = style;
    }
}
TKRadialGaugeSubtitleStyleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialGaugeSubtitleStyle]"
            },] }
];
TKRadialGaugeSubtitleStyleDirective.ctorParameters = () => [
    { type: RadRadialGaugeComponent, decorators: [{ type: Inject, args: [RadRadialGaugeComponent,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
class TKRadialNeedleStyleDirective {
    constructor(owner, _elementRef) {
        this.owner = owner;
        this._elementRef = _elementRef;
    }
    ngOnInit() {
        const style = this._elementRef.nativeElement;
        this.owner.radialNeedle.needleStyle = style;
    }
}
TKRadialNeedleStyleDirective.decorators = [
    { type: Directive, args: [{
                selector: "[tkRadialNeedleStyle]"
            },] }
];
TKRadialNeedleStyleDirective.ctorParameters = () => [
    { type: TKRadialNeedleDirective, decorators: [{ type: Inject, args: [TKRadialNeedleDirective,] }] },
    { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] }] }
];
const GAUGES_DIRECTIVES = [RadRadialGaugeComponent, TKRadialScaleDirective, TKRadialGaugeScalesDirective, TKRadialScaleStyleDirective, TKRadialScaleIndicatorsDirective, TKRadialBarIndicatorStyleDirective, TKRadialBarIndicatorDirective, TKRadialGaugeTitleStyleDirective, TKRadialNeedleStyleDirective, TKRadialNeedleDirective, TKRadialGaugeSubtitleStyleDirective];
registerElement("RadRadialGauge", () => RadRadialGauge);
registerElement("RadialScale", () => RadialScale);
registerElement("ScaleStyle", () => ScaleStyle);
registerElement("RadialBarIndicator", () => RadialBarIndicator);
registerElement("BarIndicatorStyle", () => BarIndicatorStyle);
registerElement("RadialNeedle", () => RadialNeedle);
registerElement("TitleStyle", () => TitleStyle);
registerElement("SubtitleStyle", () => SubtitleStyle);
registerElement("NeedleStyle", () => NeedleStyle);
class NativeScriptUIGaugeModule {
}
NativeScriptUIGaugeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [GAUGES_DIRECTIVES],
                exports: [GAUGES_DIRECTIVES]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { GAUGES_DIRECTIVES, NativeScriptUIGaugeModule, RadRadialGaugeComponent, TKRadialBarIndicatorDirective, TKRadialBarIndicatorStyleDirective, TKRadialGaugeScalesDirective, TKRadialGaugeSubtitleStyleDirective, TKRadialGaugeTitleStyleDirective, TKRadialNeedleDirective, TKRadialNeedleStyleDirective, TKRadialScaleDirective, TKRadialScaleIndicatorsDirective, TKRadialScaleStyleDirective };
//# sourceMappingURL=nativescript-ui-gauge-angular.js.map
